/*
 * Author: Kipp Cannon <kipp@gravity.phys.uwm.edu>
 * Revision: $Id: FrequencySeries.m4,v 1.1 2005/01/28 23:38:05 kipp Exp $
 */

#ifndef _FREQUENCYSERIES_H
#define _FREQUENCYSERIES_H

#include <lal/LALDatatypes.h>



/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyCOMPLEX8FrequencySeries (
	COMPLEX8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyCOMPLEX8FrequencySeries (
	LALStatus *status,
	COMPLEX8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
COMPLEX8FrequencySeries *XLALCreateCOMPLEX8FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateCOMPLEX8FrequencySeries (
	LALStatus *status,
	COMPLEX8FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
COMPLEX8FrequencySeries *XLALCutCOMPLEX8FrequencySeries (
	COMPLEX8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutCOMPLEX8FrequencySeries (
	LALStatus *status,
	COMPLEX8FrequencySeries **output,
	COMPLEX8FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkCOMPLEX8FrequencySeries (
	COMPLEX8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkCOMPLEX8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkCOMPLEX8FrequencySeries (
	LALStatus *status,
	COMPLEX8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyCOMPLEX16FrequencySeries (
	COMPLEX16FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyCOMPLEX16FrequencySeries (
	LALStatus *status,
	COMPLEX16FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
COMPLEX16FrequencySeries *XLALCreateCOMPLEX16FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateCOMPLEX16FrequencySeries (
	LALStatus *status,
	COMPLEX16FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
COMPLEX16FrequencySeries *XLALCutCOMPLEX16FrequencySeries (
	COMPLEX16FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutCOMPLEX16FrequencySeries (
	LALStatus *status,
	COMPLEX16FrequencySeries **output,
	COMPLEX16FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkCOMPLEX16FrequencySeries (
	COMPLEX16FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkCOMPLEX16FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkCOMPLEX16FrequencySeries (
	LALStatus *status,
	COMPLEX16FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyREAL4FrequencySeries (
	REAL4FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyREAL4FrequencySeries (
	LALStatus *status,
	REAL4FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
REAL4FrequencySeries *XLALCreateREAL4FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateREAL4FrequencySeries (
	LALStatus *status,
	REAL4FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
REAL4FrequencySeries *XLALCutREAL4FrequencySeries (
	REAL4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutREAL4FrequencySeries (
	LALStatus *status,
	REAL4FrequencySeries **output,
	REAL4FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkREAL4FrequencySeries (
	REAL4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkREAL4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkREAL4FrequencySeries (
	LALStatus *status,
	REAL4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyREAL8FrequencySeries (
	REAL8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyREAL8FrequencySeries (
	LALStatus *status,
	REAL8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
REAL8FrequencySeries *XLALCreateREAL8FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateREAL8FrequencySeries (
	LALStatus *status,
	REAL8FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
REAL8FrequencySeries *XLALCutREAL8FrequencySeries (
	REAL8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutREAL8FrequencySeries (
	LALStatus *status,
	REAL8FrequencySeries **output,
	REAL8FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkREAL8FrequencySeries (
	REAL8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkREAL8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkREAL8FrequencySeries (
	LALStatus *status,
	REAL8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyINT2FrequencySeries (
	INT2FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyINT2FrequencySeries (
	LALStatus *status,
	INT2FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
INT2FrequencySeries *XLALCreateINT2FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateINT2FrequencySeries (
	LALStatus *status,
	INT2FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
INT2FrequencySeries *XLALCutINT2FrequencySeries (
	INT2FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutINT2FrequencySeries (
	LALStatus *status,
	INT2FrequencySeries **output,
	INT2FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkINT2FrequencySeries (
	INT2FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkINT2FrequencySeries (
	LALStatus *status,
	INT2FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyINT4FrequencySeries (
	INT4FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyINT4FrequencySeries (
	LALStatus *status,
	INT4FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
INT4FrequencySeries *XLALCreateINT4FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateINT4FrequencySeries (
	LALStatus *status,
	INT4FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
INT4FrequencySeries *XLALCutINT4FrequencySeries (
	INT4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutINT4FrequencySeries (
	LALStatus *status,
	INT4FrequencySeries **output,
	INT4FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkINT4FrequencySeries (
	INT4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkINT4FrequencySeries (
	LALStatus *status,
	INT4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyINT8FrequencySeries (
	INT8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyINT8FrequencySeries (
	LALStatus *status,
	INT8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
INT8FrequencySeries *XLALCreateINT8FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateINT8FrequencySeries (
	LALStatus *status,
	INT8FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
INT8FrequencySeries *XLALCutINT8FrequencySeries (
	INT8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutINT8FrequencySeries (
	LALStatus *status,
	INT8FrequencySeries **output,
	INT8FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkINT8FrequencySeries (
	INT8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkINT8FrequencySeries (
	LALStatus *status,
	INT8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyUINT2FrequencySeries (
	UINT2FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyUINT2FrequencySeries (
	LALStatus *status,
	UINT2FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
UINT2FrequencySeries *XLALCreateUINT2FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateUINT2FrequencySeries (
	LALStatus *status,
	UINT2FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
UINT2FrequencySeries *XLALCutUINT2FrequencySeries (
	UINT2FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutUINT2FrequencySeries (
	LALStatus *status,
	UINT2FrequencySeries **output,
	UINT2FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkUINT2FrequencySeries (
	UINT2FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkUINT2FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkUINT2FrequencySeries (
	LALStatus *status,
	UINT2FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyUINT4FrequencySeries (
	UINT4FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyUINT4FrequencySeries (
	LALStatus *status,
	UINT4FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
UINT4FrequencySeries *XLALCreateUINT4FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateUINT4FrequencySeries (
	LALStatus *status,
	UINT4FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
UINT4FrequencySeries *XLALCutUINT4FrequencySeries (
	UINT4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutUINT4FrequencySeries (
	LALStatus *status,
	UINT4FrequencySeries **output,
	UINT4FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkUINT4FrequencySeries (
	UINT4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkUINT4FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkUINT4FrequencySeries (
	LALStatus *status,
	UINT4FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */




/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{XLALDestroyUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void XLALDestroyUINT8FrequencySeries (
	UINT8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesDestroyP">
\idx{LALDestroyUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesDestroyP"> */
void LALDestroyUINT8FrequencySeries (
	LALStatus *status,
	UINT8FrequencySeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{XLALCreateUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
UINT8FrequencySeries *XLALCreateUINT8FrequencySeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaF,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCreateP">
\idx{LALCreateUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCreateP"> */
void LALCreateUINT8FrequencySeries (
	LALStatus *status,
	UINT8FrequencySeries **output,
	const CHAR *name,
	LIGOTimeGPS epoch,
	REAL8 f0,
	REAL8 deltaF,
	LALUnit sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{XLALCutUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
UINT8FrequencySeries *XLALCutUINT8FrequencySeries (
	UINT8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesCutP">
\idx{LALCutUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesCutP"> */
void LALCutUINT8FrequencySeries (
	LALStatus *status,
	UINT8FrequencySeries **output,
	UINT8FrequencySeries *input,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{XLALShrinkUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
size_t XLALShrinkUINT8FrequencySeries (
	UINT8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="FrequencySeriesShrinkP">
\idx{LALShrinkUINT8FrequencySeries ()}
</lalLaTeX> <lalVerbatim file="FrequencySeriesShrinkP"> */
void LALShrinkUINT8FrequencySeries (
	LALStatus *status,
	UINT8FrequencySeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */


#endif  /* _FREQUENCYSERIES_H */
